---
Summary: `sbl` Group By
Status: Done
---

# Description

Allow calling `sbl --group-by <field>` to group by a particular field. Multiple layers of group-by can be called.

If the field is defined in the `tools.scrummd.fields` table in the config, order the output in the same order. If not, alphabetical order.

# Implementation Notes

No unit test exists for this actual output yet. I'm not really happy enough with output to test for it.
